Struct blade_render::util::FramePacer
source · pub struct FramePacer { /* private fields */ }Expand description
Utility object that encapsulates the logic of always rendering 1 frame at a time, and cleaning up the temporary resources.
Implementations
sourceimpl FramePacer
impl FramePacer
pub fn new(context: &Context) -> Self
pub fn wait_for_previous_frame(&mut self, context: &Context)
pub fn last_sync_point(&self) -> Option<&SyncPoint>
pub fn destroy(&mut self, context: &Context)
pub fn begin_frame(&mut self) -> (&mut CommandEncoder, &mut FrameResources)
pub fn end_frame(&mut self, context: &Context) -> &SyncPoint