Struct blade_render::AssetHub

source ·
pub struct AssetHub {
    pub textures: Arc<AssetManager<Baker>>,
    pub models: AssetManager<Baker>,
    pub shaders: AssetManager<Baker>,
}
A single hub to manage all assets.

Fields

textures: Arc<AssetManager<Baker>>models: AssetManager<Baker>shaders: AssetManager<Baker>

Implementations

source

impl AssetHub

source

pub fn new( target: &Path, choir: &Arc<Choir>, gpu_context: &Arc<Context> ) -> Self

Create a new hub.

source

pub fn flush( &self, command_encoder: &mut CommandEncoder, temp_buffers: &mut Vec<Buffer> )

Flush the GPU state updates into the specified command encoder.

Populates the list of temporary buffers that can be freed when the relevant submission is completely retired.

source

pub fn destroy(&mut self)

Destroy the hub contents.

source

pub fn open_context<'a, N: Into<Name>>( &'a self, base_path: &'a Path, name: N ) -> LoadContext<'_>

source

pub fn list_running_tasks(&self) -> Vec<RunningTask>